@@ -323,7 +323,7 @@ static void voiceTrigger(int32_t ch, sample_t *s, int32_t position)
 	v->hasLooped = false; // for cubic/sinc interpolation special case
 	v->samplingBackwards = false;
 	v->loopType = loopType;
-	v->sampleEnd = (loopType == LOOP_OFF) ? length : loopEnd;
+	v->sampleEnd = (loopType == LOOP_DISABLED) ? length : loopEnd;
 	v->loopStart = loopStart;
 	v->loopLength = loopLength;
 	v->position = position;
@@ -429,8 +429,7 @@ static void sendSamples16BitStereo(void *stream, uint32_t sampleBlockLength)
 		fOut = (fOut + fPrng) - fPrngStateL;
 		fPrngStateL = fPrng;
 		out32 = (int32_t)fOut;
-		CLAMP16(out32);
-		*streamPtr16++ = (int16_t)out32;
+		*streamPtr16++ = (int16_t)(CLAMP(out32, INT16_MIN, INT16_MAX));
 
 		// right channel - 1-bit triangular dithering
 		fPrng = (float)random32() * (1.0f / (UINT32_MAX+1.0f)); // -0.5f .. 0.5f
@@ -438,8 +437,7 @@ static void sendSamples16BitStereo(void *stream, uint32_t sampleBlockLength)
 		fOut = (fOut + fPrng) - fPrngStateR;
 		fPrngStateR = fPrng;
 		out32 = (int32_t)fOut;
-		CLAMP16(out32);
-		*streamPtr16++ = (int16_t)out32;
+		*streamPtr16++ = (int16_t)(CLAMP(out32, INT16_MIN, INT16_MAX));
 
 		// clear what we read from the mixing buffer
 		audio.fMixBufferL[i] = audio.fMixBufferR[i] = 0.0f;
@@ -473,7 +471,7 @@ static void doChannelMixing(int32_t bufferPosition, int32_t samplesToMix)
 	voice_t *v = voice; // normal voices
 	voice_t *r = &voice[MAX_CHANNELS]; // volume ramp fadeout-voices
 
-	const int32_t mixOffsetBias = 3 * NUM_INTERPOLATORS * 2; // 3 = loop types (off/fwd/bidi), 2 = bit depths (8-bit/16-bit)
+	const int32_t mixOffsetBias = 3 * NUM_INTERPOLATORS * 2; // 3 = loop types (off/fwd/pingpong), 2 = bit depths (8-bit/16-bit)
 
 	for (int32_t i = 0; i < song.numChannels; i++, v++, r++)
 	{
