@@ -237,7 +237,7 @@ bool loadDIGI(FILE *f, uint32_t filesize)
 
 		if (s->loopStart+s->loopLength > 2)
 		{
-			s->flags |= LOOP_FWD; // enable loop
+			s->flags |= LOOP_FORWARD; // enable loop
 		}
 		else
 		{
