@@ -22,7 +22,7 @@ static uint32_t extraSampleLengths[32-MAX_SMP_PER_INST];
 static bool loadInstrHeader(FILE *f, int32_t insNum);
 static bool loadInstrSample(FILE *f, int32_t insNum);
 static bool loadPatterns(FILE *f, int32_t numPatterns, uint16_t xmVersion);
-static void unpackPatt(uint8_t *dst, uint8_t *src, uint16_t len, int32_t numChannels);
+static void unpackPattern(note_t *p, uint8_t *src, int32_t numRows, int32_t numChannels);
 static void loadADPCMSample(FILE *f, sample_t *s); // ModPlug Tracker
 
 bool loadXM(FILE *f, uint32_t filesize)
@@ -60,13 +60,8 @@ bool loadXM(FILE *f, uint32_t filesize)
 		return false;
 	}
 
-	if (header.numChannels == 0)
-	{
-		loaderMsgBox("Error loading XM: This file is corrupt.");
-		return false;
-	}
-
-	if (header.numInstr > 256) // if >128 instruments, we fake-load up to 128 extra instruments and discard them
+	// (if >128 instruments, we fake-load up to 128 extra instruments and discard them)
+	if (header.numChannels == 0 || header.numInstr > 256)
 	{
 		loaderMsgBox("Error loading XM: This file is corrupt.");
 		return false;
@@ -90,7 +85,7 @@ bool loadXM(FILE *f, uint32_t filesize)
 	tmpLinearPeriodsFlag = !!(header.flags & 1);
 
 	if (songTmp.songLength == 0)
-		songTmp.songLength = 1; // songTmp.songTab is already empty
+		songTmp.songLength = 1; // (songTmp.orders is already zeroed, this is safe)
 	else
 		memcpy(songTmp.orders, header.orders, songTmp.songLength);
 
@@ -112,7 +107,7 @@ bool loadXM(FILE *f, uint32_t filesize)
 	{
 		// XM v1.02 and XM v1.03
 
-		for (int32_t i = 1; i <= header.numInstr; i++)
+		for (int32_t i = 0; i < header.numInstr; i++)
 		{
 			if (!loadInstrHeader(f, i))
 				return false;
@@ -121,7 +116,7 @@ bool loadXM(FILE *f, uint32_t filesize)
 		if (!loadPatterns(f, header.numPatterns, header.version))
 			return false;
 
-		for (int32_t i = 1; i <= header.numInstr; i++)
+		for (int32_t i = 0; i < header.numInstr; i++)
 		{
 			if (!loadInstrSample(f, i))
 				return false;
@@ -134,7 +129,7 @@ bool loadXM(FILE *f, uint32_t filesize)
 		if (!loadPatterns(f, header.numPatterns, header.version))
 			return false;
 
-		for (uint16_t i = 1; i <= header.numInstr; i++)
+		for (int32_t i = 0; i < header.numInstr; i++)
 		{
 			if (!loadInstrHeader(f, i))
 				return false;
@@ -147,12 +142,12 @@ bool loadXM(FILE *f, uint32_t filesize)
 	// if we temporarily loaded more than 128 instruments, clear the extra allocated memory
 	if (header.numInstr > MAX_INST)
 	{
-		for (int32_t i = MAX_INST+1; i <= header.numInstr; i++)
+		for (int32_t i = MAX_INST; i < header.numInstr; i++)
 		{
-			if (instrTmp[i] != NULL)
+			if (instrTmp[1+i] != NULL)
 			{
-				free(instrTmp[i]);
-				instrTmp[i] = NULL;
+				free(instrTmp[1+i]);
+				instrTmp[1+i] = NULL;
 			}
 		}
 	}
@@ -162,12 +157,16 @@ bool loadXM(FILE *f, uint32_t filesize)
 	** back to max 16 in the headers before loading is done.
 	*/
 	bool instrHasMoreThan16Samples = false;
-	for (int32_t i = 1; i <= MAX_INST; i++)
+	for (int32_t i = 0; i < header.numInstr; i++)
 	{
-		if (instrTmp[i] != NULL && instrTmp[i]->numSamples > MAX_SMP_PER_INST)
+		instr_t *ins = instrTmp[1+i];
+		if (ins == NULL)
+			continue;
+
+		if (ins->numSamples > MAX_SMP_PER_INST)
 		{
+			ins->numSamples = MAX_SMP_PER_INST;
 			instrHasMoreThan16Samples = true;
-			instrTmp[i]->numSamples = MAX_SMP_PER_INST;
 		}
 	}
 
@@ -189,10 +188,7 @@ bool loadXM(FILE *f, uint32_t filesize)
 static bool loadInstrHeader(FILE *f, int32_t insNum)
 {
 	uint32_t readSize;
-	instr_t *ins;
 	xmInsHdr_t ih;
-	xmSmpHdr_t *src;
-	sample_t *s;
 
 	memset(extraSampleLengths, 0, sizeof (extraSampleLengths));
 	memset(&ih, 0, sizeof (ih));
@@ -222,17 +218,17 @@ static bool loadInstrHeader(FILE *f, int32_t insNum)
 		return false;
 	}
 
-	if (insNum <= MAX_INST) // copy over instrument name
-		memcpy(songTmp.instrName[insNum], ih.name, 22);
+	if (insNum < MAX_INST) // copy over instrument name
+		memcpy(songTmp.instrName[1+insNum], ih.name, 22);
 
 	if (ih.numSamples > 0 && ih.numSamples <= 32)
 	{
-		if (!allocateTmpInstr(insNum))
+		if (!allocateTmpInstr(1+insNum))
 		{
 			loaderMsgBox("Not enough memory!");
 			return false;
 		}
-		ins = instrTmp[insNum];
+		instr_t *ins = instrTmp[1+insNum];
 
 		// copy instrument header elements to our instrument struct
 
@@ -274,38 +270,38 @@ static bool loadInstrHeader(FILE *f, int32_t insNum)
 		// if instrument contains more than 16 sample headers (unsupported), skip them
 		if (ih.numSamples > MAX_SMP_PER_INST) // can only be 0..32 at this point
 		{
-			const int32_t samplesToSkip = ih.numSamples-MAX_SMP_PER_INST;
+			const int32_t samplesToSkip = ih.numSamples - MAX_SMP_PER_INST;
 			for (int32_t j = 0; j < samplesToSkip; j++)
 			{
 				fread(&extraSampleLengths[j], 4, 1, f); // used for skipping data in loadInstrSample()
-				fseek(f, sizeof (xmSmpHdr_t)-4, SEEK_CUR);
+				fseek(f, sizeof (xmSmpHdr_t) - 4, SEEK_CUR);
 			}
 		}
 
-		s = instrTmp[insNum]->smp;
-		src = ih.smp;
-		for (int32_t j = 0; j < sampleHeadersToRead; j++, s++, src++)
+		xmSmpHdr_t *srcSmp = ih.smp;
+		sample_t *s = ins->smp;
+		for (int32_t j = 0; j < sampleHeadersToRead; j++, s++, srcSmp++)
 		{
 			// copy sample header elements to our sample struct
 
-			s->length = src->length;
-			s->loopStart = src->loopStart;
-			s->loopLength = src->loopLength;
-			s->volume = src->volume;
-			s->finetune = src->finetune;
-			s->flags = src->flags;
-			s->panning = src->panning;
-			s->relativeNote = src->relativeNote;
+			s->length = srcSmp->length;
+			s->loopStart = srcSmp->loopStart;
+			s->loopLength = srcSmp->loopLength;
+			s->volume = srcSmp->volume;
+			s->finetune = srcSmp->finetune;
+			s->flags = srcSmp->flags;
+			s->panning = srcSmp->panning;
+			s->relativeNote = srcSmp->relativeNote;
 
 			/* If the sample is 8-bit mono and nameLength (reserved) is 0xAD,
 			** then this is a 4-bit ADPCM compressed sample (ModPlug Tracker).
 			*/
-			if (src->nameLength == 0xAD && !(src->flags & (SAMPLE_16BIT | SAMPLE_STEREO)))
+			if (srcSmp->nameLength == 0xAD && !(srcSmp->flags & (SAMPLE_16BIT | SAMPLE_STEREO)))
 				s->flags |= SAMPLE_ADPCM;
 
-			memcpy(s->name, src->name, 22);
+			memcpy(s->name, srcSmp->name, 22);
 
-			// dst->dataPtr is set up later
+			// s->dataPtr is set up later
 		}
 	}
 
@@ -314,16 +310,16 @@ static bool loadInstrHeader(FILE *f, int32_t insNum)
 
 static bool loadInstrSample(FILE *f, int32_t insNum)
 {
-	if (instrTmp[insNum] == NULL)
+	instr_t *ins = instrTmp[1+insNum];
+	if (ins == NULL)
 		return true; // empty instrument, let's just pretend it got loaded successfully
 
-	int32_t numSamples = instrTmp[insNum]->numSamples;
+	int32_t numSamples = ins->numSamples;
 	if (numSamples > MAX_SMP_PER_INST)
 		numSamples = MAX_SMP_PER_INST;
 
-	sample_t *s = instrTmp[insNum]->smp;
-
-	if (insNum > MAX_INST) // insNum > 128, just skip sample data
+	sample_t *s = ins->smp;
+	if (insNum >= MAX_INST) // insNum >= 128, just skip sample data
 	{
 		for (int32_t i = 0; i < numSamples; i++, s++)
 		{
@@ -401,13 +397,13 @@ static bool loadInstrSample(FILE *f, int32_t insNum)
 	}
 
 	// skip sample headers if we have more than 16 samples in instrument
-	if (instrTmp[insNum]->numSamples > MAX_SMP_PER_INST)
+	if (ins->numSamples > MAX_SMP_PER_INST)
 	{
-		const int32_t samplesToSkip = instrTmp[insNum]->numSamples-MAX_SMP_PER_INST;
+		const int32_t samplesToSkip = ins->numSamples - MAX_SMP_PER_INST;
 		for (int32_t i = 0; i < samplesToSkip; i++)
 		{
 			if (extraSampleLengths[i] > 0)
-				fseek(f, extraSampleLengths[i], SEEK_CUR); 
+				fseek(f, extraSampleLengths[i], SEEK_CUR);
 		}
 	}
 
@@ -416,7 +412,6 @@ static bool loadInstrSample(FILE *f, int32_t insNum)
 
 static bool loadPatterns(FILE *f, int32_t numPatterns, uint16_t xmVersion)
 {
-	uint8_t tmpLen;
 	xmPatHdr_t ph;
 
 	bool pattLenWarn = false;
@@ -431,6 +426,7 @@ static bool loadPatterns(FILE *f, int32_t numPatterns, uint16_t xmVersion)
 		ph.numRows = 0;
 		if (xmVersion == 0x0102)
 		{
+			uint8_t tmpLen;
 			if (fread(&tmpLen, 1, 1, f) != 1)
 				goto pattCorrupt;
 
@@ -475,7 +471,7 @@ static bool loadPatterns(FILE *f, int32_t numPatterns, uint16_t xmVersion)
 			if (fread(tmpBuffer, 1, ph.dataSize, f) != ph.dataSize)
 				goto pattCorrupt;
 
-			unpackPatt((uint8_t *)patternTmp[i], tmpBuffer, patternNumRowsTmp[i], songTmp.numChannels);
+			unpackPattern(patternTmp[i], tmpBuffer, patternNumRowsTmp[i], songTmp.numChannels);
 			clearUnusedChannels(patternTmp[i], patternNumRowsTmp[i], songTmp.numChannels);
 		}
 
@@ -501,77 +497,73 @@ pattCorrupt:
 	return false;
 }
 
-static void unpackPatt(uint8_t *dst, uint8_t *src, uint16_t len, int32_t numChannels)
+static void unpackPattern(note_t *p, uint8_t *src, int32_t numRows, int32_t numChannels)
 {
-	if (dst == NULL)
+	if (p == NULL)
 		return;
 
-	const int32_t srcEnd = len * (sizeof (note_t) * numChannels);
-	int32_t srcIdx = 0;
+	int32_t channelsToLoad = numChannels;
+	if (channelsToLoad > MAX_CHANNELS)
+		channelsToLoad = MAX_CHANNELS;
 
-	int32_t readChannels = numChannels;
-	if (readChannels > MAX_CHANNELS)
-		readChannels = MAX_CHANNELS;
+	const int32_t unpackedBytes = numRows * (sizeof (note_t) * numChannels);
 
-	const int32_t pitch = sizeof (note_t) * (MAX_CHANNELS - numChannels);
-	for (int32_t i = 0; i < len; i++)
+	int32_t bytesWritten = 0;
+	for (int32_t i = 0; i < numRows; i++)
 	{
 		int32_t j;
-		for (j = 0; j < readChannels; j++)
+		for (j = 0; j < channelsToLoad; j++, p++)
 		{
-			if (srcIdx >= srcEnd)
-				return; // error!
+			if (bytesWritten >= unpackedBytes)
+				return; // pack error!
 
-			const uint8_t note = *src++;
-			if (note & 0x80)
+			const uint8_t byte = *src++;
+			if (byte & 128)
 			{
-				*dst++ = (note & 0x01) ? *src++ : 0;
-				*dst++ = (note & 0x02) ? *src++ : 0;
-				*dst++ = (note & 0x04) ? *src++ : 0;
-				*dst++ = (note & 0x08) ? *src++ : 0;
-				*dst++ = (note & 0x10) ? *src++ : 0;
+				p->note    = (byte &  1) ? *src++ : 0;
+				p->instr   = (byte &  2) ? *src++ : 0;
+				p->vol     = (byte &  4) ? *src++ : 0;
+				p->efx     = (byte &  8) ? *src++ : 0;
+				p->efxData = (byte & 16) ? *src++ : 0;
 			}
 			else
 			{
-				*dst++ = note;
-				*dst++ = *src++;
-				*dst++ = *src++;
-				*dst++ = *src++;
-				*dst++ = *src++;
+				p->note    = byte;
+				p->instr   = *src++;
+				p->vol     = *src++;
+				p->efx     = *src++;
+				p->efxData = *src++;
 			}
 
-			srcIdx += sizeof (note_t);
+			bytesWritten += sizeof (note_t);
 		}
 
-		// if more than 32 channels, skip rest of the channels for this row
+		// if >32 channels, skip rest of the channels for this row
 		for (; j < numChannels; j++)
 		{
-			if (srcIdx >= srcEnd)
-				return; // error!
+			if (bytesWritten >= unpackedBytes)
+				return; // pack error!
 
-			const uint8_t note = *src++;
-			if (note & 0x80)
+			const uint8_t byte = *src++;
+			if (byte & 128)
 			{
-				if (note & 0x01) src++;
-				if (note & 0x02) src++;
-				if (note & 0x04) src++;
-				if (note & 0x08) src++;
-				if (note & 0x10) src++;
+				if (byte &  1) src++;
+				if (byte &  2) src++;
+				if (byte &  4) src++;
+				if (byte &  8) src++;
+				if (byte & 16) src++;
 			}
 			else
 			{
-				src++;
-				src++;
-				src++;
-				src++;
+				src += 4;
 			}
 
-			srcIdx += sizeof (note_t);
+			bytesWritten += sizeof (note_t);
 		}
 
-		// if song has <32 channels, align pointer to next row (skip unused channels)
+		// skip unused channels if if song has <32 channels (we always allocate 32 channels)
 		if (numChannels < MAX_CHANNELS)
-			dst += pitch;
+			p += MAX_CHANNELS - numChannels;
 	}
 }
 
